==> zio-aws-mgn_2.13-5.17.129.3-sources.jar: zio/aws/mgn/model/ReplicationConfigurationReplicatedDiskStagingDiskType.scala <==
package zio.aws.mgn.model
import scala.jdk.CollectionConverters._
sealed trait ReplicationConfigurationReplicatedDiskStagingDiskType {
  def unwrap: software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType
}
object ReplicationConfigurationReplicatedDiskStagingDiskType {
  def wrap(
      value: software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType
  ): zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
    value match {
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.AUTO =>
        val r = AUTO
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.GP2 =>
        val r = GP2
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.IO1 =>
        val r = IO1
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.SC1 =>
        val r = SC1
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.ST1 =>
        val r = ST1
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.STANDARD =>
        val r = STANDARD
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.UNKNOWN_TO_SDK_VERSION
  }
  case object AUTO
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.AUTO
  }
  case object GP2
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.GP2
  }
  case object IO1
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.IO1
  }
  case object SC1
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.SC1
  }
  case object ST1
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.ST1
  }
  case object STANDARD
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.STANDARD
  }
}

==> zio-aws-mgn_2.13-5.17.145.1-sources.jar: zio/aws/mgn/model/ReplicationConfigurationReplicatedDiskStagingDiskType.scala <==
package zio.aws.mgn.model
import scala.jdk.CollectionConverters._
sealed trait ReplicationConfigurationReplicatedDiskStagingDiskType {
  def unwrap: software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType
}
object ReplicationConfigurationReplicatedDiskStagingDiskType {
  def wrap(
      value: software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType
  ): zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
    value match {
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.AUTO =>
        val r = AUTO
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.GP2 =>
        val r = GP2
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.IO1 =>
        val r = IO1
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.SC1 =>
        val r = SC1
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.ST1 =>
        val r = ST1
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.STANDARD =>
        val r = STANDARD
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.GP3 =>
        val r = GP3
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.IO2 =>
        val r = IO2
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.UNKNOWN_TO_SDK_VERSION
  }
  case object AUTO
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.AUTO
  }
  case object GP2
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.GP2
  }
  case object IO1
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.IO1
  }
  case object SC1
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.SC1
  }
  case object ST1
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.ST1
  }
  case object STANDARD
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.STANDARD
  }
  case object GP3
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.GP3
  }
  case object IO2
      extends zio.aws.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationReplicatedDiskStagingDiskType.IO2
  }
}
